@@ -1,13 +1,14 @@
 """
 Various utilities for working with images in the _mir_ project.
 """
-__version__ = "0.0.10"
+__version__ = "0.0.11"
+
 from typing import TypeVar
 
 from .image_utils import (is_valid_pil_image_from_bytes_string,
                           is_valid_pil_image_file,
                           show_pil_image,
-                          get_img_files, 
+                          get_img_files,
                           get_pil_image_size)
 
 from .image_transformers import pil2ndarray, pil_image_to_bytes_string
@@ -26,7 +27,10 @@ try:
     import torch
     import torchvision
     from torchvision import transforms
-    WITH_TORCH = True   
+
+    WITH_TORCH = True
 except ModuleNotFoundError as e:
-        print(f"An exception was raised whilst importing torch, torchvision, torchvision.transforms. Message {str(e)}")
-        pass
+    print(
+        f"WARNING: An exception was raised whilst importing torch, torchvision. Message {str(e)}")
+    print("WARNING: mir-vision-utils will not use torch and torchvision")
+    pass
